#!/usr/bin/python

import numpy as np
import statsmodels as sm
import statsmodels.distributions
import matplotlib.pyplot as plt
import sys
import os.path as path
import colorsys

def main(fname, extract=False, gnuplot=False):

    plotsX = []
    plotsY = []
    fits = []

    with open(fname) as f:
        accumulator = []
        for line in f:
            data = line.strip().split(",")
            res = float(data[2])
            tag = str(data[5])
            if not tag.startswith("MSS3_STATE"):
                accumulator.append(res)
            else:
                parts = tag.split("_")
                r = float(parts[2])
                rlow = float(parts[3])
                rhigh = float(parts[4])
                array = np.array(accumulator.copy())
                rawY = array[(array > rlow) & (array < rhigh)]
                accumulator.clear()
                ecdf = sm.distributions.ECDF(rawY)
                dataX = np.linspace(min(rawY), max(rawY))
                dataY = ecdf(dataX)

                plotsX.append(dataX)
                plotsY.append(dataY)

    if extract:
        output = open("%s_consolidated.dat" % path.splitext(fname)[0], 'w')
        for i in range(len(plotsX)):
            output.write("\"STATE %d\"\n" % (i+1))
            for j in range(len(plotsX[i])):
                output.write("%g\t%g\n" % (plotsX[i][j], plotsY[i][j]))
            output.write("\n\n")

    for i in range(len(plotsX)):

        if extract:
            p = np.polyfit(plotsX[i], plotsY[i], 1)
            fX = np.linspace(0.995*min(plotsX[i]), 1.1*max(plotsX[i]), num=200)
            #fX = np.linspace(min(plotsX[i]), max(plotsX[i]), num=200)
            fY = fX*p[0] + p[1]
            print("y = %f*x + %f" % (p[0], p[1]))
            fits.append((p[0], p[1]))
            output.write("\"Fit of STATE = %d\"\n" % (i+1))
            for j in range(len(fX)):
                output.write("%g\t%g\n" % (fX[j], fY[j]))
            output.write("\n\n")

        else:
            params = np.polyfit(plotsX[i]/1000.0, plotsY[i], 1)

            fitX = np.linspace(0.995*min(plotsX[i])/1000.0, 1.1*max(plotsX[i])/1000.0)
            fitY = fitX*params[0] + params[1]
            plt.gca().set_xlim([33, 86])
            plt.gca().set_ylim([-0.05, 1.05])
            plt.plot(plotsX[i]/1000.0, plotsY[i], '.', fitX, fitY, '-')
            plt.show()

    if extract:
        output.close()

    if gnuplot:
        base = path.splitext(fname)[0]
        gpl = open("%s_consolidated_inc.gpl" % base, 'w')
        gpl.write('plot \\\n')
        HSV = [(x*1.0/len(plotsX), 0.8,0.8) for x in range(len(plotsX))]
        RGB = map(lambda x: colorsys.hsv_to_rgb(*x), HSV)
        colors = [ "#%x%x%x" % (int(x[0]*256)-1, int(x[1]*256)-1, int(x[2]*256)-1) for x in RGB  ]
        for i in range(len(plotsX)):
            gpl.write("  '%s_consolidated.dat' i %d u ($1/1000):($2*100) w l lw 0.75 dt 3 lc rgb '#666666' ti \"\", \\\n" % (base, i+107))
            gpl.write("  '%s_consolidated.dat' i %d u ($1/1000):($2*100) w p pt 7 ps 0.5 lc '%s' ti \"\", \\\n" % (base, i, colors[i]))
        gpl.write(";\n")
        gpl.close()

if __name__ == "__main__":
    main(sys.argv[1], True, True)
